==> pointpos_api-0.2.0.tar.gz: test/promo_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Promo
void main() {
  var instance = new Promo();

  group('test Promo', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String promoType (default value: null)
    test('to test the property `promoType`', () async {
      // TODO
    });

    // List<String> assignedOutlets (default value: const [])
    test('to test the property `assignedOutlets`', () async {
      // TODO
    });

    // PromoRequirement requirement (default value: null)
    test('to test the property `requirement`', () async {
      // TODO
    });

    // PromoReward reward (default value: null)
    test('to test the property `reward`', () async {
      // TODO
    });

    // bool allowMultiple (default value: null)
    test('to test the property `allowMultiple`', () async {
      // TODO
    });

    // PromoPromoPeriod promoPeriod (default value: null)
    test('to test the property `promoPeriod`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/promo_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Promo
void main() {
  var instance = new Promo();

  group('test Promo', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // String promoType (default value: null)
    test('to test the property `promoType`', () async {
      // TODO
    });

    // List<String> assignedOutlets (default value: const [])
    test('to test the property `assignedOutlets`', () async {
      // TODO
    });

    // PromoRequirement requirement (default value: null)
    test('to test the property `requirement`', () async {
      // TODO
    });

    // PromoReward reward (default value: null)
    test('to test the property `reward`', () async {
      // TODO
    });

    // bool allowMultiple (default value: null)
    test('to test the property `allowMultiple`', () async {
      // TODO
    });

    // PromoPromoPeriod promoPeriod (default value: null)
    test('to test the property `promoPeriod`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
